@@ -50,12 +50,15 @@ class TransactionQueue(queue.Queue, object):
 
     def put(self, *args, **kwargs):
         super().put(*args, **kwargs)
-        self._wait_queue.alert_notify()
+        self.alert_notify()
 
     @property
     def alert_fileno(self):
         return self._wait_queue.alert_fileno
 
+    def alert_notify(self):
+        self._wait_queue.alert_notify()
+
 
 class Connection(object):
 
@@ -89,11 +92,10 @@ class Connection(object):
             self.poller = poller.Poller()
             self.is_running = True
             self.thread = threading.Thread(target=self.run)
-            self.thread.setDaemon(True)
+            self.thread.daemon = True
             self.thread.start()
 
     def run(self):
-        errors = 0
         while self.is_running:
             # If we fail in an Idl call, we could have missed an update
             # from the server, leaving us out of sync with ovsdb-server.
@@ -108,22 +110,10 @@ class Connection(object):
                     self.idl.run()
             except Exception as e:
                 # This shouldn't happen, but is possible if there is a bug
-                # in python-ovs
-                errors += 1
+                # in python-ovs, or an unhandled exception in overridden
+                # Idl.notify() code
                 LOG.exception(e)
-                with self.lock:
-                    self.idl.force_reconnect()
-                    try:
-                        idlutils.wait_for_change(self.idl, self.timeout)
-                    except Exception as e:
-                        # This could throw the same exception as idl.run()
-                        # or Exception("timeout"), either way continue
-                        LOG.exception(e)
-                sleep = min(2 ** errors, 60)
-                LOG.info("Trying to recover, sleeping %s seconds", sleep)
-                time.sleep(sleep)
                 continue
-            errors = 0
             txn = self.txns.get_nowait()
             if txn is not None:
                 try:
@@ -157,6 +147,10 @@ class Connection(object):
                                               timeout=self.timeout,
                                               cause='TXN queue is full') from e
 
+    def force_reconnect(self):
+        self.idl.force_reconnect()
+        self.txns.alert_notify()
+
 
 class OvsdbIdl(idl.Idl):
     def cooperative_yield(self):
