@@ -14,6 +14,9 @@
 
 import collections
 from collections import abc
+# json is not deprecated
+# pylint: disable=deprecated-module
+import json
 import logging
 import os
 import sys
@@ -121,7 +124,7 @@ def row_by_record(idl_, table, record):
     except ValueError:
         # Not a UUID string, continue lookup by other means
         pass
-    except KeyError:
+    except KeyError as e:
         if sys.platform != 'win32':
             # On Windows the name of the ports is described by the OVS schema:
             # https://tinyurl.com/zk8skhx
@@ -131,7 +134,7 @@ def row_by_record(idl_, table, record):
             # as it happens on Linux and will try to fetch the directly
             # the column instead of using the lookup table. This will raise
             # a KeyError exception on Windows.
-            raise RowNotFound(table=table, col='uuid', match=record)
+            raise RowNotFound(table=table, col='uuid', match=record) from e
 
     rl = _LOOKUP_TABLE.get(table, RowLookup(table, get_index_column(t), None))
     # no table means uuid only, no column means lookup table only has one row
@@ -154,8 +157,19 @@ class ExceptionResult(object):
         self.tb = tb
 
 
-def get_schema_helper(connection, schema_name):
-    """Create a schema helper object by querying an ovsdb-server
+def create_schema_helper(schema):
+    """Create a schema helper object based on the provided schema.
+
+    :param schema: The description of the schema
+    :type schema: dict or string
+    """
+    if isinstance(schema, str):
+        schema = json.loads(schema)
+    return idl.SchemaHelper(None, schema)
+
+
+def fetch_schema_json(connection, schema_name):
+    """Retrieve the schema json from an ovsdb-server
 
     :param connection: The ovsdb-server connection string
     :type connection: string
@@ -181,15 +195,26 @@ def get_schema_helper(connection, schema_name):
                      "%(err)s", {'conn': c,
                                  'err': os.strerror(err)})
             continue
-        elif resp.error:
+        if resp.error:
             LOG.error("TRXN error, failed to retrieve schema from %(conn)s: "
                       "%(err)s", {'conn': c,
                                   'err': resp.error})
             continue
-        return idl.SchemaHelper(None, resp.result)
+        return resp.result
     raise Exception("Could not retrieve schema from %s" % connection)
 
 
+def get_schema_helper(connection, schema_name):
+    """Create a schema helper object by querying an ovsdb-server
+
+    :param connection: The ovsdb-server connection string
+    :type connection: string
+    :param schema_name: The schema on the server to pull
+    :type schema_name: string
+    """
+    return create_schema_helper(fetch_schema_json(connection, schema_name))
+
+
 def parse_connection(connection_string):
     """Parse a connection string.
 
@@ -206,17 +231,27 @@ def parse_connection(connection_string):
     return [c.strip() for c in connection_string.split(',')]
 
 
-def wait_for_change(_idl, timeout, seqno=None):
+def wait_for_change(_idl, timeout=None, seqno=None):
+    """Wait for the Idl seqno to change
+
+    :param _idl: The Idl instance
+    :type _idl: ovs.db.idl.Idl
+    :param timeout: raise a TimeoutException after if timeout > 0/not None
+    :type timeout: int (seconds) or None
+    """
+    if timeout and timeout <= 0:
+        timeout = None
     if seqno is None:
         seqno = _idl.change_seqno
-    stop = time.time() + timeout
+    stop = time.time() + timeout if timeout else None
     while _idl.change_seqno == seqno and not _idl.run():
         ovs_poller = poller.Poller()
         _idl.wait(ovs_poller)
-        ovs_poller.timer_wait(timeout * 1000)
+        if timeout:
+            ovs_poller.timer_wait(timeout * 1000)
         ovs_poller.block()
-        if time.time() > stop:
-            raise Exception("Timeout")  # TODO(twilson) use TimeoutException?
+        if stop and time.time() >= stop:
+            raise exceptions.TimeoutException()
 
 
 def get_column_value(row, col):
@@ -447,3 +482,29 @@ def frozen_row(row):
         uuid=row.uuid,
         **{col: getattr(row, col)
            for col in row._table.columns if hasattr(row, col)})
+
+
+def has_table(idl_, table):
+    """Check if a table exists in the IDL schema.
+
+    :param _idl: The Idl instance
+    :type _idl: ovs.db.idl.Idl
+    :param table: The name of the table to check for
+    :type table: str
+    :return: True if the table exists, False otherwise
+    """
+    return table in idl_.tables
+
+
+def table_has_column(idl_, table, column):
+    """Check if a column exists in a specific table of the IDL schema.
+
+    :param _idl: The Idl instance
+    :type _idl: ovs.db.idl.Idl
+    :param table: The name of the table to check
+    :type table: str
+    :param column: The name of the column to check for
+    :type column: str
+    :return: True if the column exists in the table, False otherwise
+    """
+    return table in idl_.tables and column in idl_.tables[table].columns
